<?php

declare(strict_types=1);

namespace Drupal\noahs_ai\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Provides a Noahs ai form.
 */
final class NoahsAiSettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId(): string {
    return 'noahs_ai_noahs_ai_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['noahs_ai.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state): array {
    $config = $this->config('noahs_ai.settings');

    //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
    $form['openai_api_key'] = [
      '#type' => 'textfield',
      '#title' => $this->t('OpenAI API Key'),
      '#default_value' => $config->get('openai_api_key'),
      '#maxlength' => 512, // Puedes ajustar este valor si es necesario
      '#description' => $this->t('To use this feature, you need an OpenAI API key. You can obtain your API key by creating an account at <a href=":link" target="_blank">OpenAI</a>. Once logged in, go to your account settings → <strong>API keys</strong>, and click on <strong>Create new secret key</strong>. Copy the key and paste it here. Make sure to keep it safe and do not share it publicly.', [
        ':link' => 'https://platform.openai.com/signup',
      ]),
      '#required' => TRUE,
    ];

    $form['openai_model'] = [
      '#type' => 'select',
      '#title' => $this->t('OpenAI Model'),
      '#default_value' => $config->get('openai_model') ?? 'gpt-3.5-turbo',
      '#options' => [
        'gpt-3.5-turbo' => $this->t('GPT-3.5 Turbo – Fast and affordable'),
        'gpt-4' => $this->t('GPT-4 – Most accurate, but slower and more expensive'),
        'gpt-4-turbo' => $this->t('GPT-4 Turbo – Best balance of power and speed'),
      ],
      '#description' => $this->t('Choose the model you want to use for AI responses. GPT-4 Turbo is recommended for high-quality text generation.'),
      '#required' => TRUE,
    ];


    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state): void {
    // @todo Validate the form here.
    // Example:
    // @code
    //   if (mb_strlen($form_state->getValue('message')) < 10) {
    //     $form_state->setErrorByName(
    //       'message',
    //       $this->t('Message should be at least 10 characters.'),
    //     );
    //   }
    // @endcode
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state): void {
    $this->messenger()->addStatus($this->t('The message has been sent.'));
    $form_state->cleanValues();
    $values = $form_state->getValues();
    $config = $this->config('noahs_ai.settings');

    foreach ($values as $key => $value) {
      if (is_array($value)) {
        // Si es un array, se asume que son valores anidados.
        foreach ($value as $sub_key => $sub_value) {
          $config->set("$key.$sub_key", $sub_value);
        }
      }
      else {
        // Si no es un array, se asume un campo simple.
        $config->set($key, $value);
      }
    }

    $config->save();

    // Call the parent method without returning it
    parent::submitForm($form, $form_state);
  
  }

}
