<?php

/**
 * @file
 * Contains \Drupal\noahs_page_builder\Controller\NoahsThemesController.
 */

namespace Drupal\noahs_page_builder\Controller;

use Drupal\Core\Controller\ControllerBase;
use Symfony\Component\HttpFoundation\Response;
use Drupal\Core\File\FileSystemInterface;
use Drupal\file\Entity\File;
use Symfony\Component\HttpFoundation\JsonResponse;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\BinaryFileResponse;
use Symfony\Component\HttpFoundation\ResponseHeaderBag;


class NoahsThemesController extends ControllerBase{

  

  /**
  * {@inheritdoc}
  */
  public function getTheme(Request $request){
    $data = json_decode($request->getContent(),);
    // $data['url'] = 'https://page-builder.ddev.site/modules/custom/noahs_page_builder/assets/noahs-themes/test_template.json';
    $json_string = file_get_contents($data->url);
    $widget = json_decode($json_string);

    return new JsonResponse(noahs_page_builder_html_generated(json_decode($widget->settings)));
  }

  /**
   * {@inheritdoc}
   */
  public function modalThemes(){
    return new JsonResponse(['html' => $this->listOfThemes()]);
  }

  /**
   * {@inheritdoc}
   */
  private function listOfThemes(){

    $schema = \Drupal::database()->schema();
    $builder = null;
    if ($schema->tableExists('noahs_page_builder_pro_theme')) {
      $builder = \Drupal::database()->select('noahs_page_builder_pro_theme', 'mt')
        ->fields('mt', ['id', 'title'])
        ->execute()
        ->fetchAll();
    }


    $noahs_themes = [];
    $noahs_themes_categories = [];
    $module_path = NOAHS_PAGE_BUILDER_PATH;

    $themes_folder_path = $module_path . '/assets/noahs-themes/';
    $file_system = \Drupal::service('file_system');

    $files = $file_system->scanDirectory($themes_folder_path, '/\.json$/');
    
    global $base_root;
    foreach ($files as $index => $file) {
      $json_string = file_get_contents($base_root . '/' . $file->uri);
      $data = json_decode($json_string, true); 
      $data['url'] = $base_root . '/' . $file->uri;
      $noahs_themes[] = $data;
      $noahs_themes_categories[$data['category']] = $data['category'];
    }
    

    $output = '<div class="modal fade modal-type-themes" id="noahsSectionThemeModal" tabindex="-1">';
    $output .= '<div class="modal-dialog modal-xl">';
    $output .= '<div class="modal-content">';
     $output .= '<div class="modal-header">
        <h5 class="modal-title">'.t('Themes').'</h5>
        <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
      </div>';
    $output .= '<div class="modal-body">';
    $output .= '<nav>';
    $output .= '<div class="nav nav-tabs" id="nav-tab" role="tablist">';
    $output .= '<button class="nav-link active" id="nav-noahs-theme-tab" data-bs-toggle="tab" data-bs-target="#nav-noahs-theme" type="button" role="tab" aria-controls="nav-noahs-theme" aria-selected="true">' .t('Noahs themes') .'</button>';
    $output .= '<button class="nav-link" id="nav-user-noahs-theme-tab" data-bs-toggle="tab" data-bs-target="#nav-user-noahs-theme" type="button" role="tab" aria-controls="nav-user-noahs-theme" aria-selected="true">' .t('My themes') .'</button>';
    $output .= '</div>';
    $output .= '</nav>';
    $output .= '<div class="tab-content p-3 border bg-light" id="nav-tabContent">';
    $output .= '<form>';
    $output .= '<div class="mb-3">';
    $output .= '<label for="searchThemes" class="form-label">' .t('Search theme') .'</label>';
    $output .= '<input type="text" class="form-control element-admin" id="searchThemes">';
    $output .= '</div>';
    $output .= '</form>';
    $output .= '<div class="tab-pane fade active show" id="nav-noahs-theme" role="tabpanel" aria-labelledby="nav-noahs-theme-tab">';

    $output .= '<div class="d-flex justify-content-center mb-4">';
    $output .= '<div class="btn-group" role="group" aria-label="Filter by category">';
    $output .= '<input name="filterThemeCheck" type="radio" class="btn-check filter-theme-check" id="all_themes" autocomplete="off" checked>';
    $output .= '<label class="btn btn-admin btn-outline-primary" for="all_themes">'.t('All').'</label>';
    foreach ($noahs_themes_categories as $k => $item) {
      $output .= '<input type="radio" name="filterThemeCheck" class="btn-check filter-theme-check" id="btncheck_'.$k.'" autocomplete="off">';
      $output .= '<label class="btn btn-outline-primary btn-admin" for="btncheck_'.$k.'">'.t($item).'</label>';
    }

    $output .= '</div>';
    $output .= '</div>';

    $output .= '<div class="row row-cols-3 g-4">';

    foreach ($noahs_themes as $k => $item) {

      $output .= '<div class="col" data-bs-toggle="tooltip" data-bs-placement="top" data-category="'.$item['category'].'" data-title="'.$item['title'].'">';
      $output .= '<div class="card noahs_paste_default_theme h-100" data-url="'.$item['url'].'" data-group="noahs-theme">
                  <img src="'.$item['thumbnail'].'" class="card-img-top" alt="...">
                  <div class="card-body">
                    <h5 class="card-title">'.$item['title'].'</h5>
                </div>
      </div>';
    
      $output .= '</div>';
    }
    $output .= '</div>';
    $output .= '</div>';
    $output .= '<div class="tab-pane fade" id="nav-user-noahs-theme" role="tabpanel" aria-labelledby="nav-user-noahs-theme-tab">';
    $output .= '<div class="d-flex flex-wrap g-2">';
    if ($builder) {
      foreach ($builder as $k => $item) {
        $output .= '<div class="col-4" data-group="user-noahs-theme" data-bs-toggle="tooltip" data-bs-placement="top">';
        $output .= '<div class="p-3 border d-flex justify-content-center noahs_paste_saved_theme" data-id="' . $item->id . '">' . $item->title . '</div>';
        $output .= '</div>';
      }
    }else{
      $link = '<a href="https://noahs-creator.com" target="_blank">Noahs PRO</a>';
      $output .= '<div class="col-12"><h4>' . sprintf('You need to install %s to use this feature.', $link) . '</h4></div>';  
    }

    $output .= '</div>';
    $output .= '</div>';
    $output .= '</div>';
    $output .= '<div class="modal-footer px-0 pb-0 justify-content-end">
                <button type="button" class="btn btn-danger btn-admin" data-bs-dismiss="modal">'. t('Cancel') . '</button>';
    $output .= '</div>';
    $output .= '</div>';
    $output .= '</div>';
    $output .= '</div>';
    $output .= '</div>';

    return $output;

  }

}

